;****************************************************************************
; BIOS patch code for
; - ASUS P2B-F (with hardware monitor) 1014 beta 003 (1014f.003)
; - ASUS P2B-F (without hardware monitor) 1014 beta 003 (1014fn.003)
; - ASUS P2B (with hardware monitor) 1014 beta 003 (1014.003)
; - ASUS P2B (without hardware monitor) 1014 beta 003 (1014nh.003)
; - ASUS P2B-D 1014 beta 003 (1014d.003)
; - ASUS P2B-DS 1014 beta 003 (1014ds.003)
; - ASUS P2L97 (with hardware monitor) 1010 beta 004 (1010.004)
; - ASUS P2L97 (without hardware monitor) 1010 beta 004 (1010m.004)
; - ASUS P2L97-S 1010 beta 004 (1010S.004)
; - ASUS P2-99 (with hardware monitor) 1013 beta 005 (1013.005)
; - ASUS P2-99 (without hardware monitor) 1013 beta 005 (1013d9.005)
; - ASUS P2B-N (with ATI Rage IIC) 1014 beta 003 (1014niic.003)
; - ASUS P2B-N (with ATI Rage Pro) 1014 beta 003 (1014npro.003)
; - ASUS P2L97A 1010 beta 004 (1010a.004)
; - ASUS P2B-S 1014 beta 003 (1014s.003)
;****************************************************************************
;
; Main file containing new code and data to be added to the BIOS
;
;****************************************************************************
;
; Changes:
; - support new multipilers for CPU speed/FSB calculation
; - added Setup Utility "Enable" option for Symbios SCSI BIOS to force
;   loading the ROM module even if no matching adapter is present
; - experimental support for Via C3 processors
;
;****************************************************************************

;----------------------------------------------------------------------------
; assembler directives/options
;----------------------------------------------------------------------------

[map symbols bin\mainF000.map]
bits 16
cpu 686

;----------------------------------------------------------------------------
; includes
;----------------------------------------------------------------------------

%include	"macro.def"		; macro definitions
%include	"bios.equ"		; addresses of BIOS code and data
					; used in patch routines
%include	"mainE000.equ"		; addresses of E000 segment patch
					; code and data

;----------------------------------------------------------------------------
; origin
;----------------------------------------------------------------------------

patchStart:
	org 	patchLocF000		; go to free location in F000 segment
					; to place patch data and code into

;----------------------------------------------------------------------------
; data
;----------------------------------------------------------------------------

%ifdef PATCH_SYMBIOS
%ifdef ONBOARD_SCSI
OnbSCSIOptions:
%else					; ONBOARD_SCSI
SymbiosOptions:
%endif					; ONBOARD_SCSI
	db	"Auto    ", 0
	db	"Disabled", 0
	db	"Enabled ", 0
%endif					; PATCH_SYMBIOS

%if FEATURE_LEVEL <= 1
SpeedTab:
	db	"Manual ", 0
SpeedTabFreq:
	db	"233MHz ", 0
	db	"240MHz ", 0
	db	"266MHz ", 0
	db	"270MHz ", 0
	db	"300MHz ", 0
	db	" ", 1
	db	" ", 1
%endif					; FEATURE_LEVEL

;----------------------------------------------------------------------------
; code
;----------------------------------------------------------------------------

%if FEATURE_LEVEL >= 3

; =============== F U N C T I O N   C H U N K ===============================


programChipset:
	call	0E000h:getMultFar
	mov	bl, al
	jmp	resumeChipset

%endif					; FEATURE_LEVEL


%if FEATURE_LEVEL = 0

; =============== S U B R O U T I N E =======================================


getL2CacheSizeF:
	call	0E000h:getL2CacheSzFar
	retn

%endif					; FEATURE_LEVEL

%if FEATURE_LEVEL <= 1

; =============== F U N C T I O N   C H U N K ===============================


printSpeedSetup:
	mov	si, SpeedTabFreq+2	; overwrite menu item for three digit
	mov	cx, 3			; CPU speed ...
	cmp	ax, 1000
	jb	short .lengthKnown
	inc	si			; ... or four digit CPU speed
	inc	cx

.lengthKnown:
	mov	word [cs:si+1], 'MH'
	mov	byte [cs:si+3], 'z'
	jmp	printSpeedLoop

%endif					; FEATURE_LEVEL
